@@ -13,8 +13,9 @@ jd_span <- function(type,d0,d1,n0,n1){
 }
 
 
-specX13_jd2r <- function(spec = NA, context_dictionary = NULL,
-                         extra_info = FALSE){
+spec_regarima_X13_jd2r <- function(spec = NA, context_dictionary = NULL,
+                         extra_info = FALSE,
+                         freq = NA){
 
   #Estimate
   preliminary.check <- spec$getBasic()$isPreliminaryCheck()
@@ -49,71 +50,73 @@ specX13_jd2r <- function(spec = NA, context_dictionary = NULL,
     tradingdays.option <- .jcall(jtd,"S","getTradingDays")
   }
 
-  tradingdays.autoadjust<-.jcall(jtd,"Z","isAutoAdjust")
-  tradingdays.leapyear <-.jcall(jtd,"S","getLengthOfPeriod")
-  tradingdays.stocktd <-.jcall(jtd,"I","getW")
-  tradingdays.test <-.jcall(jtd,"S","getTest")
-  easter.enabled <-.jcall(jeaster,"Z","isEnabled")
-  easter.julian <-.jcall(jeaster,"Z","isJulian")
-  easter.duration <-.jcall(jeaster,"I","getDuration")
-  easter.test <-.jcall(jeaster,"S","getTest")
+  tradingdays.autoadjust <- .jcall(jtd,"Z","isAutoAdjust")
+  tradingdays.leapyear <- .jcall(jtd,"S","getLengthOfPeriod")
+  tradingdays.stocktd <- .jcall(jtd,"I","getW")
+  tradingdays.test <- .jcall(jtd,"S","getTest")
+  easter.enabled <- .jcall(jeaster,"Z","isEnabled")
+  easter.julian <- .jcall(jeaster,"Z","isJulian")
+  easter.duration <- .jcall(jeaster,"I","getDuration")
+  easter.test <- .jcall(jeaster,"S","getTest")
 
   #Outlier
-  joutlier<-.jcall(spec,"Ljdr/spec/x13/OutlierSpec;","getOutliers")
-  joutlier.span <-.jcall(joutlier,"Ljdr/spec/ts/SpanSelector;","getSpan")
+  joutlier <- .jcall(spec,"Ljdr/spec/x13/OutlierSpec;","getOutliers")
+  joutlier.span <- .jcall(joutlier,"Ljdr/spec/ts/SpanSelector;","getSpan")
 
-  outlier.enabled<-.jcall(joutlier,"Z","isEnabled")
+  outlier.enabled <- .jcall(joutlier,"Z","isEnabled")
   outlier.type <- .jcall(joutlier.span,"S","getType")
   outlier.d0 <- .jcall(joutlier.span,"S","getD0")
   outlier.d1 <- .jcall(joutlier.span,"S","getD1")
   outlier.n0 <- .jcall(joutlier.span,"I","getN0")
   outlier.n1 <- .jcall(joutlier.span,"I","getN1")
-  outlier.span <- jd_span(type= outlier.type,d0=outlier.d0,d1=outlier.d1,n0=outlier.n0,n1=outlier.n1)
-  outlier.ao <-.jcall(joutlier,"Z","isAO")
-  outlier.tc <-.jcall(joutlier,"Z","isTC")
-  outlier.ls <-.jcall(joutlier,"Z","isLS")
-  outlier.so <-.jcall(joutlier,"Z","isSO")
-  outlier.usedefcv <-.jcall(joutlier,"Z","isDefaultVa")
-  outlier.cv <-.jcall(joutlier,"D","getVa")
-  outlier.method <-.jcall(joutlier,"S","getMethod")
-  outlier.tcrate <-.jcall(joutlier,"D","getTCRate")
+  outlier.span <- jd_span(type = outlier.type,
+                          d0 = outlier.d0, d1 = outlier.d1,
+                          n0 = outlier.n0, n1 = outlier.n1)
+  outlier.ao <- .jcall(joutlier, "Z", "isAO")
+  outlier.tc <- .jcall(joutlier, "Z", "isTC")
+  outlier.ls <- .jcall(joutlier, "Z", "isLS")
+  outlier.so <- .jcall(joutlier, "Z", "isSO")
+  outlier.usedefcv <- .jcall(joutlier, "Z", "isDefaultVa")
+  outlier.cv <- .jcall(joutlier, "D", "getVa")
+  outlier.method <- .jcall(joutlier, "S", "getMethod")
+  outlier.tcrate <- .jcall(joutlier, "D", "getTCRate")
 
   #Arima
-  jarima<-.jcall(spec,"Ljdr/spec/x13/ArimaSpec;","getArima")
+  jarima <- .jcall(spec, "Ljdr/spec/x13/ArimaSpec;", "getArima")
 
-  automdl.enabled <-.jcall(jarima,"Z","isAmiEnabled")
-  automdl.acceptdefault <-.jcall(jarima,"Z","isAcceptDefault")
-  automdl.cancel <-.jcall(jarima,"D","getCancel")
-  automdl.ub1 <-.jcall(jarima,"D","getUb1")
-  automdl.ub2 <-.jcall(jarima,"D","getUb2")
-  automdl.mixed  <-.jcall(jarima,"Z","isMixed")
-  automdl.balanced <-.jcall(jarima,"Z","isBalanced")
-  automdl.armalimit <-.jcall(jarima,"D","getTsig")
-  automdl.reducecv <-.jcall(jarima,"D","getPredCV")
-  automdl.ljungboxlimit <-.jcall(jarima,"D","getPcr")
-  automdl.ubfinal <-.jcall(jarima,"D","getUbFinal")
-  arima.mu <-.jcall(jarima,"Z","isMean")
-  arima.p <-.jcall(jarima,"I","getP")
-  arima.d <-.jcall(jarima,"I","getD")
-  arima.q <-.jcall(jarima,"I","getQ")
-  arima.bp <-.jcall(jarima,"I","getBP")
-  arima.bd <-.jcall(jarima,"I","getBD")
-  arima.bq <-.jcall(jarima,"I","getBQ")
+  automdl.enabled <- .jcall(jarima, "Z", "isAmiEnabled")
+  automdl.acceptdefault <- .jcall(jarima,"Z","isAcceptDefault")
+  automdl.cancel <- .jcall(jarima,"D","getCancel")
+  automdl.ub1 <- .jcall(jarima,"D","getUb1")
+  automdl.ub2 <- .jcall(jarima,"D","getUb2")
+  automdl.mixed  <- .jcall(jarima,"Z","isMixed")
+  automdl.balanced <- .jcall(jarima,"Z","isBalanced")
+  automdl.armalimit <- .jcall(jarima,"D","getTsig")
+  automdl.reducecv <- .jcall(jarima,"D","getPredCV")
+  automdl.ljungboxlimit <- .jcall(jarima,"D","getPcr")
+  automdl.ubfinal <- .jcall(jarima,"D","getUbFinal")
+  arima.mu <- .jcall(jarima,"Z","isMean")
+  arima.p <- .jcall(jarima,"I","getP")
+  arima.d <- .jcall(jarima,"I","getD")
+  arima.q <- .jcall(jarima,"I","getQ")
+  arima.bp <- .jcall(jarima,"I","getBP")
+  arima.bd <- .jcall(jarima,"I","getBD")
+  arima.bq <- .jcall(jarima,"I","getBQ")
 
   #span matrix
-  type<-c(estimate.type,outlier.type)
-  d0<-c(estimate.d0,outlier.d0)
-  d1<-c(estimate.d1,outlier.d1)
-  n0<-c(estimate.n0,outlier.n0)
-  n1<-c(estimate.n1,outlier.n1)
+  type <- c(estimate.type,outlier.type)
+  d0 <- c(estimate.d0,outlier.d0)
+  d1 <- c(estimate.d1,outlier.d1)
+  n0 <- c(estimate.n0,outlier.n0)
+  n1 <- c(estimate.n1,outlier.n1)
 
-  span<-data.frame(type=type,d0=d0,d1=d1,n0=n0,n1=n1)
-  rownames(span)<-c("estimate","outlier")
+  span <- data.frame(type=type,d0=d0,d1=d1,n0=n0,n1=n1)
+  rownames(span) <- c("estimate","outlier")
 
   #Default values:
 
   arima.coef <- FALSE
-  userdef_spec <-list(specification = data.frame(outlier = FALSE,
+  userdef_spec <- list(specification = data.frame(outlier = FALSE,
                                                  outlier.coef = FALSE,
                                                  variables = FALSE,
                                                  variables.coef = FALSE,
@@ -235,7 +238,7 @@ specX13_jd2r <- function(spec = NA, context_dictionary = NULL,
 
     td_var_description <- data.frame(type = rep("Calendar",length(var_names)),
                                      coeff = NA, row.names = var_names)
-    if(identical(result$userdef_spec$variables$description, NA)){
+    if(identical_na(result$userdef_spec$variables$description)){
       result$userdef_spec$variables$description <- td_var_description
     }else{
       result$userdef_spec$variables$description <- rbind(result$userdef_spec$variables$description,
@@ -251,7 +254,7 @@ specX13_jd2r <- function(spec = NA, context_dictionary = NULL,
       })
       var_series <- ts(simplify2array(var_series),
                        start = start(var_series[[1]]), frequency = frequency(var_series[[1]]))
-      if(!identical(result$userdef_spec$variables$series, NA)){
+      if(!identical_na(result$userdef_spec$variables$series)){
         var_series <- ts.union(result$userdef_spec$variables$series, var_series)
       }
       if(is.mts(var_series))
@@ -261,6 +264,85 @@ specX13_jd2r <- function(spec = NA, context_dictionary = NULL,
     }
   }
 
+  ## Ramp effects
+  core_regression <- jregression$getCore()$getRegression()
+  jramps <- core_regression$getRamps()
+  nb_ramps <- core_regression$getRampsCount()
+  if (nb_ramps > 0) {
+    var_names <- sapply(seq_len(nb_ramps), function(x) jramps[[x]]$getDescription())
+
+    result$userdef_spec$specification$variables <-
+      TRUE
+
+    coeff <- NA
+    if (core_regression$hasFixedCoefficients()) {
+      coeff <- sapply(seq_len(nb_ramps), function(i){
+        jramp <- jramps[[i]]
+        ramp_name <- jramp$getName()
+        fixed_coeff <- core_regression$getFixedCoefficients(ramp_name)
+        if (is.null(fixed_coeff)) {
+          NA
+        }else{
+          fixed_coeff
+        }
+      })
+      result$userdef_spec$specification$variables.coef <- TRUE
+    }
+
+    td_var_description <- data.frame(type = rep("Series", length(var_names)),
+                                     coeff = coeff, row.names = var_names)
+    if (identical_na(result$userdef_spec$variables$description)) {
+      result$userdef_spec$variables$description <-
+        td_var_description
+    }else{
+      result$userdef_spec$variables$description <-
+        rbind(result$userdef_spec$variables$description,
+              td_var_description)
+    }
+
+    if (!is.na(freq) || !identical_na(result$userdef_spec$variables$series)) {
+      if (is.na(freq))
+        freq <- frequency(result$userdef_spec$variables$series)
+
+      if (!identical_na(result$userdef_spec$variables$series)) {
+        start_ts <- start(result$userdef_spec$variables$series)
+        end_ts <- end(result$userdef_spec$variables$series)
+        ramp_series <- lapply(seq_len(nb_ramps), function(i){
+          jramp <- jramps[[i]]
+          jstart <- jramp$getStart()
+          jend <- jramp$getEnd()
+
+          start_ramp <- c(jstart$getYear(), jstart$getMonth())
+          end_ramp <- c(jend$getYear(), jend$getMonth())
+          ramp(start = start_ts, end = end_ts,
+               start_ramp = start_ramp, end_ramp = end_ramp,
+               frequency = freq)
+        })
+      } else {
+        ramp_series <- lapply(seq_len(nb_ramps), function(i){
+          jramp <- jramps[[i]]
+          jstart <- jramp$getStart()
+          jend <- jramp$getEnd()
+
+          start_ramp <- c(jstart$getYear(), jstart$getMonth())
+          end_ramp <- c(jend$getYear(), jend$getMonth())
+          ramp(start_ramp = start_ramp, end_ramp = end_ramp,
+               frequency = freq)
+        })
+      }
+      ramp_series <- ts(simplify2array(ramp_series),
+                        start = start(ramp_series[[1]]),
+                        frequency = frequency(ramp_series[[1]]))
+      if (!identical_na(result$userdef_spec$variables$series)) {
+        ramp_series <- ts.union(result$userdef_spec$variables$series, ramp_series)
+      }
+      if (is.mts(ramp_series))
+        colnames(ramp_series) <- rownames(result$userdef_spec$variables$description)
+
+      result$userdef_spec$variables$series <- ramp_series
+    }
+  }
+
   Phi <- jarima$getPhi()
   BPhi <- jarima$getBPhi()
   Theta <- jarima$getTheta()
@@ -280,13 +362,13 @@ specX13_jd2r <- function(spec = NA, context_dictionary = NULL,
   result
 }
 
-specTS_jd2r<- function(spec = NA, context_dictionary = NULL,
-                       extra_info = FALSE){
+spec_TRAMO_jd2r <- function(spec = NA, context_dictionary = NULL,
+                       extra_info = FALSE, freq = NA){
 
   #Estimate
   preliminary.check <- spec$getBasic()$isPreliminaryCheck()
-  jestimate <-.jcall(spec,"Ljdr/spec/tramoseats/EstimateSpec;","getEstimate")
-  jest.span <-.jcall(jestimate,"Ljdr/spec/ts/SpanSelector;","getSpan")
+  jestimate <- .jcall(spec,"Ljdr/spec/tramoseats/EstimateSpec;","getEstimate")
+  jest.span <- .jcall(jestimate,"Ljdr/spec/ts/SpanSelector;","getSpan")
 
   estimate.type <- .jcall(jest.span,"S","getType")
   estimate.d0 <- .jcall(jest.span,"S","getD0")
@@ -496,10 +578,24 @@ specTS_jd2r<- function(spec = NA, context_dictionary = NULL,
 
     result$userdef_spec$specification$variables <-
       TRUE
+    coeff <- NA
+    # if (core_regression$hasFixedCoefficients()) {
+    #   # coeff <- sapply(seq_len(nb_ramps), function(i){
+    #   #   jramp <- jramps[[i]]
+    #   #   ramp_name <- jramp$getName()
+    #   #   fixed_coeff <- core_regression$getFixedCoefficients(ramp_name)
+    #   #   if (is.null(fixed_coeff)) {
+    #   #     NA
+    #   #   }else{
+    #   #     fixed_coeff
+    #   #   }
+    #   # })
+    #   # result$userdef_spec$specification$variables.coef <- TRUE
+    # }
 
     td_var_description <- data.frame(type = rep("Calendar",length(var_names)),
-                                     coeff = NA, row.names = var_names)
-    if(identical(result$userdef_spec$variables$description, NA)){
+                                     coeff = coeff, row.names = var_names)
+    if(identical_na(result$userdef_spec$variables$description)){
       result$userdef_spec$variables$description <- td_var_description
     }else{
       result$userdef_spec$variables$description <- rbind(result$userdef_spec$variables$description,
@@ -515,7 +611,7 @@ specTS_jd2r<- function(spec = NA, context_dictionary = NULL,
       })
       var_series <- ts(simplify2array(var_series),
                        start = start(var_series[[1]]), frequency = frequency(var_series[[1]]))
-      if(!identical(result$userdef_spec$variables$series, NA)){
+      if(!identical_na(result$userdef_spec$variables$series)){
         var_series <- ts.union(result$userdef_spec$variables$series, var_series)
       }
       if(is.mts(var_series))
@@ -525,6 +621,84 @@ specTS_jd2r<- function(spec = NA, context_dictionary = NULL,
     }
   }
 
+  ## Ramp effects
+  core_regression <- jregression$getCore()$getRegression()
+  jramps <- core_regression$getRamps()
+  nb_ramps <- core_regression$getRampsCount()
+  if (nb_ramps > 0) {
+    var_names <- sapply(seq_len(nb_ramps), function(x) jramps[[x]]$getDescription())
+
+    result$userdef_spec$specification$variables <-
+      TRUE
+    coeff <- NA
+    if (core_regression$hasFixedCoefficients()) {
+      coeff <- sapply(seq_len(nb_ramps), function(i){
+        jramp <- jramps[[i]]
+        ramp_name <- jramp$getName()
+        fixed_coeff <- core_regression$getFixedCoefficients(ramp_name)
+        if (is.null(fixed_coeff)) {
+          NA
+        }else{
+          fixed_coeff
+        }
+      })
+      result$userdef_spec$specification$variables.coef <- TRUE
+    }
+
+    td_var_description <- data.frame(type = rep("Series", length(var_names)),
+                                     coeff = coeff, row.names = var_names)
+    if (identical_na(result$userdef_spec$variables$description)) {
+      result$userdef_spec$variables$description <-
+        td_var_description
+    }else{
+      result$userdef_spec$variables$description <-
+        rbind(result$userdef_spec$variables$description,
+              td_var_description)
+    }
+
+    if (!is.na(freq) || !identical_na(result$userdef_spec$variables$series)) {
+      if (is.na(freq))
+        freq <- frequency(result$userdef_spec$variables$series)
+
+      if (!identical_na(result$userdef_spec$variables$series)) {
+        start_ts <- start(result$userdef_spec$variables$series)
+        end_ts <- end(result$userdef_spec$variables$series)
+        ramp_series <- lapply(seq_len(nb_ramps), function(i){
+          jramp <- jramps[[i]]
+          jstart <- jramp$getStart()
+          jend <- jramp$getEnd()
+
+          start_ramp <- c(jstart$getYear(), jstart$getMonth())
+          end_ramp <- c(jend$getYear(), jend$getMonth())
+          ramp(start = start_ts, end = end_ts,
+               start_ramp = start_ramp, end_ramp = end_ramp,
+               frequency = freq)
+        })
+      } else {
+        ramp_series <- lapply(seq_len(nb_ramps), function(i){
+          jramp <- jramps[[i]]
+          jstart <- jramp$getStart()
+          jend <- jramp$getEnd()
+
+          start_ramp <- c(jstart$getYear(), jstart$getMonth())
+          end_ramp <- c(jend$getYear(), jend$getMonth())
+          ramp(start_ramp = start_ramp, end_ramp = end_ramp,
+               frequency = freq)
+        })
+      }
+      ramp_series <- ts(simplify2array(ramp_series),
+                       start = start(ramp_series[[1]]),
+                       frequency = frequency(ramp_series[[1]]))
+      if (!identical_na(result$userdef_spec$variables$series)) {
+        ramp_series <- ts.union(result$userdef_spec$variables$series, ramp_series)
+      }
+      if (is.mts(ramp_series))
+        colnames(ramp_series) <- rownames(result$userdef_spec$variables$description)
+
+      result$userdef_spec$variables$series <- ramp_series
+    }
+  }
+
   #Arima
   Phi <- jarima$getPhi()
   BPhi <- jarima$getBPhi()
@@ -546,12 +720,12 @@ specTS_jd2r<- function(spec = NA, context_dictionary = NULL,
 }
 
 specX11_jd2r <- function(spec = NA, freq = NA){
-  jx11 <-.jcall(spec,"Ljdr/spec/x13/X11Spec;","getX11")
+  jx11 <- .jcall(spec,"Ljdr/spec/x13/X11Spec;","getX11")
 
-  if(!is.na(freq)){
+  if (!is.na(freq)) {
     .jcall(jx11,"V","setFreq", as.integer(freq))
     fullseasonalma <- .jcall(jx11,"[S","getFullSeasonalMA")
-    if(!is.null(fullseasonalma) && length(unique(fullseasonalma))  > 1){
+    if (!is.null(fullseasonalma) && length(unique(fullseasonalma)) > 1) {
       seasonalma <- paste(fullseasonalma, collapse = ", ")
     }else{
       seasonalma <- .jcall(jx11,"S","getSeasonalMA")
@@ -560,30 +734,41 @@ specX11_jd2r <- function(spec = NA, freq = NA){
     seasonalma <- .jcall(jx11,"S","getSeasonalMA")
   }
 
-  mode <-.jcall(jx11,"S","getMode")
-  seasonalComp <-.jcall(jx11,"Z","isSeasonal")
-  lsigma <-.jcall(jx11,"D","getLSigma")
-  usigma <-.jcall(jx11,"D","getUSigma")
+  mode <- .jcall(jx11,"S","getMode")
+  seasonalComp <- .jcall(jx11,"Z","isSeasonal")
+  lsigma <- .jcall(jx11,"D","getLSigma")
+  usigma <- .jcall(jx11,"D","getUSigma")
   trendAuto <- .jcall(jx11,"Z","isAutoTrendMA")
   trendma <- .jcall(jx11,"I","getTrendMA")
-  fcasts<- .jcall(jx11,"I","getForecastHorizon")
+  fcasts <- .jcall(jx11,"I","getForecastHorizon")
   bcasts <- .jcall(jx11,"I","getBackcastHorizon")
   excludeFcasts <- .jcall(jx11,"Z","isExcludefcst")
+  calendarSigma <- jx11$getCalendarSigma()$toString()
+  sigmaVector <- .jcall(jx11,returnSig = "[S", "getSigmavec") #TODO
+  if (length(sigmaVector) == 0) {
+    sigmaVector <- NA
+  }else{
+    sigmaVector <- paste(sigmaVector, collapse = ", ")
+  }
 
   var <- data.frame(mode,seasonalComp,lsigma,usigma,trendAuto,trendma,seasonalma,
-                    fcasts,bcasts,excludeFcasts,
+                    fcasts, bcasts,
+                    calendarSigma, sigmaVector,
+                    excludeFcasts,
                     stringsAsFactors = FALSE)
   names(var) <- sprintf("x11.%s",
                         c("mode","seasonalComp","lsigma","usigma",
                           "trendAuto","trendma","seasonalma",
-                          "fcasts","bcasts","excludeFcasts"))
+                          "fcasts","bcasts",
+                          "calendarSigma", "sigmaVector",
+                          "excludeFcasts"))
   return(var)
 }
 
 specSeats_jd2r <- function(spec = NA){
 
-  jseats <-.jcall(spec,"Ljdr/spec/tramoseats/SeatsSpec;","getSeats")
-
+  jseats <- .jcall(spec,"Ljdr/spec/tramoseats/SeatsSpec;","getSeats")
+  predictionLength <- .jcall(jseats,"I","getPredictionLength")
   approx <- .jcall(jseats,"S","getApproximationMode")
   maBoundary <- .jcall(jseats,"D","getXl")
   trendBoundary <- .jcall(jseats,"D","getRMod")
@@ -592,9 +777,10 @@ specSeats_jd2r <- function(spec = NA){
   seasTol <- .jcall(jseats,"D","getEpsPhi")
   method <- .jcall(jseats,"S","getMethod")
 
-  var <- list(approx,maBoundary,trendBoundary,seasdBoundary,seasdBoundary1,seasTol,
+  var <- list(predictionLength, approx,maBoundary,trendBoundary,seasdBoundary,seasdBoundary1,seasTol,
               method)
-  names(var) <- c("approx","maBoundary","trendBoundary","seasdBoundary","seasdBoundary1","seasTol",
+  names(var) <- c("predictionLength", "approx", "maBoundary", "trendBoundary",
+                  "seasdBoundary","seasdBoundary1","seasTol",
                   "method")
   return(var)
 
@@ -736,7 +922,9 @@ arimaCoef_jd2r <- function(jparams){
                                   1:len)
   data_param
 }
-specX13_r2jd <- function(rspec = NA, jdspec =NA){
+spec_regarima_X13_r2jd <- function(rspec = NA, jdspec = NA){
+  if (is.null(s_estimate(rspec)))
+    return(.jnew("jdr/spec/ts/Utility$Dictionary"))
 
   est <- s_estimate(rspec)
   trans <- s_transform(rspec)
@@ -861,7 +1049,7 @@ specX13_r2jd <- function(rspec = NA, jdspec =NA){
   return(jdictionary)
 }
 
-specTS_r2jd <- function(rspec = NA, jdspec =NA){
+spec_TRAMO_r2jd <- function(rspec = NA, jdspec =NA){
 
   est <- s_estimate(rspec)
   trans <- s_transform(rspec)
@@ -990,41 +1178,60 @@ specTS_r2jd <- function(rspec = NA, jdspec =NA){
   return(jdictionary)
 }
 
-specX11_r2jd <-function( rspec = NA, jdspec = NA , freq = NA)
-{
+specX11_r2jd <- function(rspec = NA, jdspec = NA , freq = NA){
   x11 <- s_x11(rspec)
-  jx11 <-.jcall(jdspec,"Ljdr/spec/x13/X11Spec;","getX11")
+  jx11 <- .jcall(jdspec,"Ljdr/spec/x13/X11Spec;","getX11")
 
-  seasonalma <- unlist(strsplit(as.character(x11[[7]]),split=", "))
-  len <- length(seasonalma)
+  seasonalma <- unlist(strsplit(as.character(x11[["x11.seasonalma"]]),
+                                split = ", "))
+  len.ma <- length(seasonalma)
 
-  .jcall(jx11,"V","setMode",as.character(x11[[1]]))
-  .jcall(jx11,"V","setSeasonal",as.logical(x11[[2]]))
-  .jcall(jx11,"V","setLSigma",as.numeric(x11[[3]]))
-  .jcall(jx11,"V","setUSigma",as.numeric(x11[[4]]))
-  if (x11[[5]]==TRUE){
-    .jcall(jx11,"V","setTrendMA",as.integer(x11[[6]]))
-    .jcall(jx11,"V","setAutoTrendMA",as.logical(x11[[5]]))
+  .jcall(jx11,"V","setMode",as.character(x11[["x11.mode"]]))
+  .jcall(jx11,"V","setSeasonal",as.logical(x11[["x11.seasonalComp"]]))
+  .jcall(jx11,"V","setLSigma",as.numeric(x11[["x11.lsigma"]]))
+  .jcall(jx11,"V","setUSigma",as.numeric(x11[["x11.usigma"]]))
+  if (x11[["x11.trendAuto"]]) {
+    .jcall(jx11,"V","setTrendMA",as.integer(x11[["x11.trendma"]]))
   }else{
-    .jcall(jx11,"V","setAutoTrendMA",as.logical(x11[[5]]))
-    .jcall(jx11,"V","setTrendMA",as.integer(x11[[6]]))
+    .jcall(jx11,"V","setAutoTrendMA",as.logical(x11[["x11.trendAuto"]]))
+    .jcall(jx11,"V","setTrendMA",as.integer(x11[["x11.trendma"]]))
   }
-  if (len ==1){
-    .jcall(jx11,"V","setSeasonalMA",seasonalma)
+  .jcall(jx11,"V","setFreq", as.integer(freq))
+  if (len.ma == 1) {
+    .jcall(jx11, "V", "setSeasonalMA", seasonalma)
     seasma <- seasonalma
-  }else if (len != freq) {
+  }else if (len.ma != freq) {
     .jcall(jx11,"V","setSeasonalMA","Msr")
-    warning(paste0("wrong frequency of the x11.seasonalma (",len," instead of ",freq,").",
-            "\nPre-specified seasonal filters will be ignored (x11.seasonalma=\"Msr\")."), call. = FALSE)
+    warning(paste0("wrong frequency of the x11.seasonalma (",
+                   len.ma, " instead of ", freq, ").",
+            "\nPre-specified seasonal filters will be ignored (x11.seasonalma=\"Msr\")."),
+            call. = FALSE)
     seasma <- "Msr"
   } else {
-    .jcall(jx11,"V","setFreq", as.integer(freq))
+
     .jcall(jx11,"V","setFullSeasonalMA",seasonalma)
-    seasma <- as.character(x11[[7]])
+    seasma <- as.character(x11[["x11.seasonalma"]])
   }
-  .jcall(jx11,"V","setForecastHorizon",as.integer(x11[[8]]))
-  .jcall(jx11,"V","setBackcastHorizon",as.integer(x11[[9]]))
-  .jcall(jx11,"V","setExcludefcst",as.logical(x11[[10]]))
+  .jcall(jx11, "V", "setForecastHorizon", as.integer(x11[["x11.fcasts"]]))
+  .jcall(jx11, "V", "setBackcastHorizon", as.integer(x11[["x11.bcasts"]]))
+
+  .jcall(jx11, "V", "setCalendarSigma", x11[["x11.calendarSigma"]])
+
+  if (x11[["x11.calendarSigma"]] == "Select" &&
+      !identical_na(x11[["x11.sigmaVector"]])) {
+    # sigmaVector is change only if x11.calendarSigma is set to "Select"
+    sigmaVector <- unlist(strsplit(as.character(x11[["x11.sigmaVector"]]),
+                                  split = ", "))
+    if (length(sigmaVector) != freq) {
+      warning(paste0("Wrong frequency of the x11.sigmaVector (",
+                     length(sigmaVector), " instead of ", freq, ").",
+                     "\nThis parameter will be ignored."), call. = FALSE)
+    } else {
+      .jcall(jx11, "V", "setSigmavec", sigmaVector)
+    }
+
+  }
+  .jcall(jx11, "V", "setExcludefcst", as.logical(x11[["x11.excludeFcasts"]]))
 
   return(seasma)
 }
@@ -1034,13 +1241,14 @@ specSeats_r2jd <- function(rspec = NA, jdspec = NA){
   seats <- s_seats(rspec)
   jseats <-.jcall(jdspec,"Ljdr/spec/tramoseats/SeatsSpec;","getSeats")
 
-  .jcall(jseats,"V","setApproximationMode", as.character(seats[[1]]))
-  .jcall(jseats,"V","setXl", as.numeric(seats[[2]]))
-  .jcall(jseats,"V","setRMod", as.numeric(seats[[3]]))
-  .jcall(jseats,"V","setSMod", as.numeric(seats[[4]]))
-  .jcall(jseats,"V","setSMod1", as.numeric(seats[[5]]))
-  .jcall(jseats,"V","setEpsPhi",as.numeric(seats[[6]]))
-  .jcall(jseats,"V","setMethod", as.character(seats[[7]]))
+  .jcall(jseats,"V","setPredictionLength", as.integer(seats[["seats.predictionLength"]]))
+  .jcall(jseats,"V","setApproximationMode", as.character(seats[["seats.approx"]]))
+  .jcall(jseats,"V","setXl", as.numeric(seats[["seats.maBoundary"]]))
+  .jcall(jseats,"V","setRMod", as.numeric(seats[["seats.trendBoundary"]]))
+  .jcall(jseats,"V","setSMod", as.numeric(seats[["seats.seasdBoundary"]]))
+  .jcall(jseats,"V","setSMod1", as.numeric(seats[["seats.seasdBoundary1"]]))
+  .jcall(jseats,"V","setEpsPhi",as.numeric(seats[["seats.seasTol"]]))
+  .jcall(jseats,"V","setMethod", as.character(seats[["seats.method"]]))
 
 }
 
